==> zio-aws-amplifyuibuilder_2.13-7.21.15.12-sources.jar: zio/aws/amplifyuibuilder/model/UpdateThemeRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateThemeRequest(
    appId: String,
    environmentName: String,
    id: Uuid,
    clientToken: Optional[String] = Optional.Absent,
    updatedTheme: zio.aws.amplifyuibuilder.model.UpdateThemeData
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest = {
    import UpdateThemeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
      .builder()
      .appId(appId: java.lang.String)
      .environmentName(environmentName: java.lang.String)
      .id(Uuid.unwrap(id): java.lang.String)
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .updatedTheme(updatedTheme.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.UpdateThemeRequest.wrap(buildAwsValue())
}
object UpdateThemeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.UpdateThemeRequest =
      zio.aws.amplifyuibuilder.model.UpdateThemeRequest(
        appId,
        environmentName,
        id,
        clientToken.map(value => value),
        updatedTheme.asEditable
      )
    def appId: String
    def environmentName: String
    def id: Uuid
    def clientToken: Optional[String]
    def updatedTheme: zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getId: ZIO[Any, Nothing, Uuid] = ZIO.succeed(id)
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getUpdatedTheme: ZIO[
      Any,
      Nothing,
      zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly
    ] = ZIO.succeed(updatedTheme)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ) extends zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val environmentName: String = impl.environmentName(): String
    override val id: Uuid =
      zio.aws.amplifyuibuilder.model.primitives.Uuid(impl.id())
    override val clientToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => value: String)
    override val updatedTheme
        : zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly =
      zio.aws.amplifyuibuilder.model.UpdateThemeData.wrap(impl.updatedTheme())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ): zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifyuibuilder_3-5.17.104.11-sources.jar: zio/aws/amplifyuibuilder/model/UpdateThemeRequest.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateThemeRequest(
    appId: String,
    clientToken: Option[String] = None,
    environmentName: String,
    id: Uuid,
    updatedTheme: zio.aws.amplifyuibuilder.model.UpdateThemeData
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest = {
    import UpdateThemeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
      .builder()
      .appId(appId: java.lang.String)
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .environmentName(environmentName: java.lang.String)
      .id(Uuid.unwrap(id): java.lang.String)
      .updatedTheme(updatedTheme.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly =
    zio.aws.amplifyuibuilder.model.UpdateThemeRequest.wrap(buildAwsValue())
}
object UpdateThemeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifyuibuilder.model.UpdateThemeRequest =
      zio.aws.amplifyuibuilder.model.UpdateThemeRequest(
        appId,
        clientToken.map(value => value),
        environmentName,
        id,
        updatedTheme.asEditable
      )
    def appId: String
    def clientToken: Option[String]
    def environmentName: String
    def id: Uuid
    def updatedTheme: zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly
    def getAppId: ZIO[Any, Nothing, String] = ZIO.succeed(appId)
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getEnvironmentName: ZIO[Any, Nothing, String] =
      ZIO.succeed(environmentName)
    def getId: ZIO[Any, Nothing, Uuid] = ZIO.succeed(id)
    def getUpdatedTheme: ZIO[
      Any,
      Nothing,
      zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly
    ] = ZIO.succeed(updatedTheme)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ) extends zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly {
    override val appId: String = impl.appId(): String
    override val clientToken: Option[String] =
      scala.Option(impl.clientToken()).map(value => value: String)
    override val environmentName: String = impl.environmentName(): String
    override val id: Uuid =
      zio.aws.amplifyuibuilder.model.primitives.Uuid(impl.id())
    override val updatedTheme
        : zio.aws.amplifyuibuilder.model.UpdateThemeData.ReadOnly =
      zio.aws.amplifyuibuilder.model.UpdateThemeData.wrap(impl.updatedTheme())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.UpdateThemeRequest
  ): zio.aws.amplifyuibuilder.model.UpdateThemeRequest.ReadOnly = new Wrapper(
    impl
  )
}
